/**************************************************************************
*  Copyright (c) 2019 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  18.05.2019  mifi  First Version, tested with a DE1-SoC Board.
**************************************************************************/
#if !defined(__FPGA_DE1SOC__)
#define __FPGA_DE1SOC__

/**************************************************************************
*  Includes
**************************************************************************/
#include <stdint.h>
#include "hps_0.h"

/**************************************************************************
*  Global Definitions
**************************************************************************/

#define __IO            volatile

#define HPS_FPGA_BASE   0xC0000000
#define LW_HPS_FPGA     0xFF200000

typedef struct
{
   __IO uint32_t ID;
   __IO uint32_t Time;   
} SYSID_TypeDef;

typedef struct
{
   __IO uint32_t Data;
   __IO uint32_t Dir;
   __IO uint32_t IRQ;
   __IO uint32_t Edge;
   __IO uint32_t Set;
   __IO uint32_t Clr;
} PIO_TypeDef;

#define SYSID     ((SYSID_TypeDef*)(LW_HPS_FPGA + SYSID_QSYS_BASE))
#define LED       ((PIO_TypeDef*)  (LW_HPS_FPGA + LED_PIO_BASE))
#define DIPSW     ((PIO_TypeDef*)  (LW_HPS_FPGA + DIPSW_PIO_BASE))
#define BUTTON    ((PIO_TypeDef*)  (LW_HPS_FPGA + BUTTON_PIO_BASE))

/**************************************************************************
*  Macro Definitions
**************************************************************************/

/**************************************************************************
*  Functions Definitions
**************************************************************************/

#endif /* !__FPGA_DE1SOC__ */

/*** EOF ***/
